@@ -434,19 +434,6 @@ class RecommendationSchema(Configuration):
     """ The name of the column that specifies ratings """
 
 
-@datamodel(proto=data_pb.DatasetTestSuite)
-class DatasetTestSuite(Configuration):
-    MultiDatasetTests: TestSuite = TestSuite()
-    DatasetTests: TestSuite = TestSuite()
-    """ DatasetTests contains tests for the whole dataset """
-    MultiColumnTests: TestSuite = TestSuite()
-    """ MultiColumnTests defines tests for multiple columns from the dataset """
-    ColumnTests: TestSuite = TestSuite()
-    """ ColumnTests defines assertions for columns from the dataset """
-    FileTests: TestSuite = TestSuite()
-    """ FileTests defines assertions for the contents of the data file """
-
-
 MDTimeSeriesSchema = TimeSeriesSchema
 MDRecommendationSchema = RecommendationSchema
 
@@ -460,8 +447,6 @@ class Schema(Configuration):
     """ The time-series schema, which sets time-series specific parameters """
     RecommendationSchema: MDRecommendationSchema = None
     """ The recommendation schema, which is used for the recommendation ML task """
-    TestTemplate: DatasetTestSuite = DatasetTestSuite()
-    """ The specification for test rules which will be performed on new Datasets """
 
 
 @datamodel(proto=data_pb.RelationshipSpec)
@@ -622,6 +607,14 @@ class DatasetSpec(Configuration):
     """
     Used for prediction dataset, contain a reference to the predictor resource that created this dataset
     """
+    GenerateFeatureHistogram:bool = False
+    """
+    Used for prediction dataset, contain a reference to the predictor resource that created this dataset
+    """
+    UnitTests: TestSuite = TestSuite()
+    """
+    The collection of tests.
+    """
 
 
 @datamodel(proto=data_pb.OutlierStat)
@@ -888,5 +881,9 @@ class DatasetStatus(ImmutableConfiguration):
     StartTime: Time = None
     """ The time that the system started processing the Dataset, usually after the creation of the object """
     EndTime: Time = None
-    """ The time that the Dataset finished processing, either due to completion or failure """
+    """ The time that the system started processing the Dataset, usually after the creation of the object """
+    FeatureHistogramRef: ObjectReference = ObjectReference()
+    """ The feature histogram reference """
+    UnitTestResult: TestSuiteResult = TestSuiteResult()
+    """ The unit test result """
     Conditions: List[DatasetCondition] = field(default_factory=lambda : [])
