@@ -257,7 +257,7 @@ class PredictorStatus(Configuration):
     LastPredictionDataset: Time = None
     """ Last time the the predictor perform a prediction"""
     Feedback: FeedbackTestStatus = FeedbackTestStatus()
-    """ Ground Truth is the status of the ground truth tests """
+    """ Feedback is the status of the ground truth tests """
     Drift: DriftDetectionStatus = DriftDetectionStatus()
     """ Drift is the status of the drift status"""
     LastUpdated: Time = None
