@@ -92,83 +92,6 @@ class SubtaskType(Enum):
     NoneSubtask = "none"
 
 
-class Metric(Enum):
-    Accuracy = "accuracy"
-    AveragePrecision = "average-precision"
-    BalancedAccuracy = "balanced-accuracy"
-    F1Binary = "f1"
-    F1Micro = "f1-micro"
-    F1Macro = "f1-macro"
-    F1Weighted = "f1-weighted"
-    F1Samples = "f1-samples"
-    PrecisionBinary = "precision"
-    PrecisionMicro = "precision-micro"
-    PrecisionMacro = "precision-macro"
-    PrecisionWeighted = "precision-weighted"
-    PrecisionSamples = "precision-samples"
-    RecallBinary = "recall"
-    RecallMacro = "recall-macro"
-    RecallMicro = "recall-micro"
-    RecallWeighted = "recall-weighted"
-    RecallSamples = "recall-samples"
-    LogLoss = "log-loss"
-    RocAuc = "auc"
-    RocAucMicro = "auc-micro"
-    RocAucMacro = "auc-macro"
-    RocAucWeighted = "auc-weighted"
-    PRRocAuc = "pr-auc"
-    PRRocAucMicro = "pr-auc-micro"
-    PRRocAucMacro = "pr-auc-macro"
-    PRRocAucWeighted = "pr-auc-weighted"
-    ZeroOne = "zero-one"
-    HammingLoss = "hamming-loss"
-    HingeLoss = "hinge-loss"
-    JacquardScore = "jacquard-loss"
-    MatthewsCorrCoef = "mcc"
-    Fp = "fp"
-    Fn = "fn"
-    Tn = "tn"
-    Tp = "tp"
-    Tpr = "tpr"
-    Fpr = "fpr"
-    Tnr = "tnr"
-    MCC = "matthews-corr-coef"
-    ExplainedVariance = "explained-variance"
-    MaxError = "max-error"
-    MAE = "mae"
-    MSE = "mse"
-    MSLE = "msle"
-    RMSE = "rmse"
-    RMSLE = "rmsle"
-    MedianAbsoluteError = "median-absolute-error"
-    R2 = "r2"
-    AdjR2 = "adj-r2"
-    MeanPoissonDeviance = "mean_poisson_deviance"
-    MeanGammaDeviance = "mean-gamma-deviance"
-    MeanTweedieDeviance = "mean-tweedie-deviance"
-    MAPE = "mape"
-    MAZE = "maze"
-    MDAPE = "mdape"
-    SMAPE = "smape"
-    AdjustedMutualInfoScore = "adjusted-mutual-info-score"
-    AdjustedRandScore = "adjusted-rand-score"
-    CompletenessScore = "completeness-score"
-    FowlkesMallowsScore = "fowlkes-mallows-score"
-    HomogeneityScore = "homogeneity-score"
-    MutualInfoScore = "mutual-info-score"
-    NormalizedMutualInfoScore = "normalized-mutual-info-score"
-    VMeasureScore = "v-measure-score"
-    P50Latency = "p50-latency"
-    P95Latency = "p95-latency"
-    P99Latency = "p99-latency"
-    Cpu = "cpu"
-    Gpu = "gpu"
-    Mem = "mem"
-    GpuMem = "gpu-mem"
-    ReqSec = "req-per-sec"
-    UncrainPredictionPercent = "uncertain-prediction-percent"
-    Null = "none"
-
 
 class Imputation(Enum):
     RemoveRowsWithMissingValues = "remove-rows-with-missing-values"
